@@ -5,11 +5,13 @@ mod filter;
 mod id;
 mod summary;
 
+use std::ffi::OsStr;
 use std::io::Result;
 use std::io::{BufWriter, Write};
 use std::path::{Path, PathBuf};
 
 use clap::ArgMatches;
+use glob::glob;
 use indexmap::IndexSet;
 use log::LevelFilter;
 use log4rs::append::console::ConsoleAppender;
@@ -86,20 +88,39 @@ trait InputCli {
         Path::new(
             matches
                 .value_of("input")
-                .expect("CANNOT FIND AN INPUT FILE"),
+                .expect("Failed parsing an input value"),
         )
     }
 
     fn parse_dir_input<'a>(&self, matches: &'a ArgMatches) -> &'a Path {
-        Path::new(matches.value_of("dir").expect("CANNOT READ DIR PATH"))
+        Path::new(matches.value_of("dir").expect("Failed parsing a dir value"))
     }
 
     fn parse_input_wcard(&self, matches: &ArgMatches) -> Vec<PathBuf> {
-        matches
+        let inputs = matches
             .values_of("wildcard")
-            .expect("FAILED PARSING npercent")
+            .expect("Failed parsing wildcard values")
             .map(PathBuf::from)
-            .collect()
+            .collect::<Vec<PathBuf>>();
+        if cfg!(windows) {
+            let inputs = inputs
+                .iter()
+                .map(|t| OsStr::new(t).to_string_lossy())
+                .collect::<Vec<_>>();
+            let files: Vec<PathBuf> = inputs
+                .iter()
+                .flat_map(|i| {
+                    glob(i)
+                        .expect("Failed globbing files")
+                        .filter_map(|ok| ok.ok())
+                        .collect::<Vec<PathBuf>>()
+                })
+                .collect();
+            assert!(!files.is_empty(), "Empty folders!");
+            files
+        } else {
+            inputs
+        }
     }
 
     fn get_files(&self, dir: &Path, input_fmt: &InputFmt) -> Vec<PathBuf> {
@@ -118,20 +139,14 @@ trait InputCli {
 
     fn parse_input_fmt(&self, matches: &ArgMatches) -> InputFmt {
         let input_fmt = matches
-            .value_of("format")
-            .expect("CANNOT READ FORMAT INPUT");
+            .value_of("input-format")
+            .expect("Failed parsing an input format value");
         match input_fmt {
             "auto" => InputFmt::Auto,
             "fasta" => InputFmt::Fasta,
             "nexus" => InputFmt::Nexus,
             "phylip" => InputFmt::Phylip,
-            _ => panic!(
-                "UNSUPPORTED FORMAT. \
-        THE PROGRAM ONLY ACCEPT fasta, fasta-int, nexus, nexus-int, and phylip. \
-        ALL IN lowercase. \
-        YOUR INPUT: {} ",
-                input_fmt
-            ),
+            _ => unreachable!("Unknown input format. Supported format: auto, fasta, nexus, phylip"),
         }
     }
 
@@ -184,13 +199,17 @@ trait InputPrint {
 
 trait OutputCli {
     fn parse_output<'a>(&self, matches: &'a ArgMatches) -> PathBuf {
-        PathBuf::from(matches.value_of("output").expect("CANNOT READ OUTPUT PATH"))
+        PathBuf::from(
+            matches
+                .value_of("output")
+                .expect("Failed parsing an output value"),
+        )
     }
 
     fn parse_output_fmt(&self, matches: &ArgMatches) -> OutputFmt {
         let output_fmt = matches
             .value_of("output-format")
-            .expect("CANNOT READ FORMAT INPUT");
+            .expect("Failed parsing ouput format");
         match output_fmt {
             "nexus" => OutputFmt::Nexus,
             "phylip" => OutputFmt::Phylip,
@@ -198,12 +217,7 @@ trait OutputCli {
             "nexus-int" => OutputFmt::NexusInt,
             "fasta-int" => OutputFmt::FastaInt,
             "phylip-int" => OutputFmt::PhylipInt,
-            _ => panic!(
-                "UNSUPPORTED FORMAT. \
-        THE PROGRAM ONLY ACCEPT fasta, fasta-int, nexus, nexus-int, phylip, and phylip-int. ALL IN lowercase. \
-        YOUR INPUT: {} ",
-                output_fmt
-            ),
+            _ => unreachable!("Please, specify the correct output format!"),
         }
     }
 }
@@ -212,7 +226,7 @@ trait PartCLi {
     fn parse_partition_fmt(&self, matches: &ArgMatches) -> PartitionFmt {
         let part_fmt = matches
             .value_of("partition")
-            .expect("CANNOT READ PARTITION FORMAT");
+            .expect("Failed parsing partition format");
         if matches.is_present("codon") {
             self.parse_partition_fmt_codon(part_fmt)
         } else {
@@ -244,8 +258,8 @@ trait PartCLi {
             _ => {
                 if let PartitionFmt::Charset | PartitionFmt::CharsetCodon = part_fmt {
                     panic!(
-                        "CANNOT WRITE EMBEDDED-NEXUS PARTITION TO NON-NEXUS OUTPUT. \
-                MAYBE YOU MEAN TO WRITE THE PARTITION TO 'charset' INSTEAD."
+                        "Cannot write embedded-nexus partition 'charset' to non-nexus output. \
+                Maybe you mean to write the partition to 'nexus' instead."
                     )
                 }
             }
