@@ -20,7 +20,13 @@ impl InputCli for SummaryParser<'_> {
 
 impl InputPrint for SummaryParser<'_> {}
 
-impl OutputCli for SummaryParser<'_> {}
+impl OutputCli for SummaryParser<'_> {
+    fn parse_output<'a>(&self, matches: &'a ArgMatches) -> PathBuf {
+        let output = matches.value_of("output").expect("CANNOT READ OUTPUT PATH");
+        let csv = format!("{}_per_locus", output);
+        PathBuf::from(csv).with_extension("csv")
+    }
+}
 
 pub(in crate::cli) struct SummaryParser<'a> {
     matches: &'a ArgMatches<'a>,
@@ -49,7 +55,7 @@ impl<'a> SummaryParser<'a> {
             InputType::File => self.get_stats_file(task_desc),
             InputType::Dir => {
                 let dir = self.parse_dir_input(self.matches);
-                let files = self.get_files(dir, &self.input_fmt);
+                let files = self.get_files(&dir, &self.input_fmt);
                 self.print_input_multi(&Some(dir), task_desc, files.len(), &self.input_fmt);
                 self.get_stats_multiple(&files);
             }
@@ -63,7 +69,7 @@ impl<'a> SummaryParser<'a> {
 
     fn get_stats_multiple(&self, files: &[PathBuf]) {
         let output = self.parse_output(self.matches);
-        SeqStats::new(&self.input_fmt, output, self.interval, &self.datatype).get_stats_dir(files);
+        SeqStats::new(&self.input_fmt, &output, self.interval, &self.datatype).get_stats_dir(files);
     }
 
     fn get_stats_file(&self, task_desc: &str) {
@@ -71,7 +77,7 @@ impl<'a> SummaryParser<'a> {
         let input = Path::new(self.parse_file_input(self.matches));
         let output = self.parse_output(self.matches);
         self.print_input_file(input, task_desc, &self.input_fmt);
-        SeqStats::new(&self.input_fmt, output, self.interval, &self.datatype)
+        SeqStats::new(&self.input_fmt, &output, self.interval, &self.datatype)
             .get_seq_stats_file(input);
     }
 
